function cont_con

% CONT_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.14 $ $Date: 1998/10/16 23:19:13 $

helpwin('cont_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  cont_con
%
%Double click on any function for more information
%
%  Control System Toolbox.
%  Version 4.2 (R11)  15-Jul-1998
% 
%  What's new.
%    Readme      - New features and enhancements in this version.
% 
%  Creation of LTI models.
%    tf          - Create a transfer function model.
%    zpk         - Create a zero/pole/gain model.
%    ss          - Create a state-space model.
%    dss         - Create a descriptor state-space model.
%    frd         - Create a frequency response data model.
%    filt        - Specify a digital filter.
%    set         - Set/modify properties of LTI models.
%    ltimodels   - Detailed help on various types of LTI models.
%    ltiprops    - Detailed help on available LTI properties.
%    
%  Data extraction.
%    tfdata      - Extract numerator(s) and denominator(s).
%    zpkdata     - Extract zero/pole/gain data.
%    ssdata      - Extract state-space matrices.
%    dssdata     - Descriptor version of SSDATA.
%    frdata      - Extract frequency response data.
%    get         - Access values of LTI model properties.
% 
%  Model dimensions and characteristics.
%    class       - Model type ('tf', 'zpk', 'ss', or 'frd').
%    isa         - Test if LTI model is of given type.
%    size        - Model sizes and order.
%    ndims       - Number of dimensions.
%    isempty     - True for empty LTI models.
%    isct        - True for continuous-time models.
%    isdt        - True for discrete-time models.
%    isproper    - True for proper LTI models.
%    issiso      - True for single-input/single-output models.
%    reshape     - Reshape array of LTI models.
% 
%  Conversions.
%    tf          - Conversion to transfer function.
%    zpk         - Conversion to zero/pole/gain.
%    ss          - Conversion to state space.
%    frd         - Conversion to frequency data.
%    chgunits    - Change units of FRD model frequency points.
%    c2d         - Continuous to discrete conversion.
%    d2c         - Discrete to continuous conversion.
%    d2d         - Resample discrete-time model.
% 
%  Overloaded arithmetic operations.
%    + and -     - Add and subtract LTI systems (parallel connection).
%    *           - Multiply LTI systems (series connection).
%    \           - Left divide -- sys1\sys2 means inv(sys1)*sys2.
%    /           - Right divide -- sys1/sys2 means sys1*inv(sys2).
%    ^           - LTI model powers.
%    '           - Pertransposition.
%    .'          - Transposition of input/output map.
%    [..]        - Concatenate LTI models along inputs or outputs.
%    stack       - Stack LTI models/arrays along some array dimension.
%    inv         - Inverse of an LTI system.
% 
%  Model dynamics.
%    pole, eig   - System poles.
%    zero        - System (transmission) zeros.
%    pzmap       - Pole-zero map.
%    dcgain      - D.C. (low frequency) gain.
%    norm        - Norms of LTI systems.
%    covar       - Covariance of response to white noise.
%    damp        - Natural frequency and damping of system poles.
%    esort       - Sort continuous poles by real part.
%    dsort       - Sort discrete poles by magnitude.
% 
%  Time delays.
%    hasdelay    - True for models with time delays.
%    totaldelay  - Total delay between each input/output pair.
%    delay2z     - Replace delays by poles at z=0 or FRD phase shift.
%    pade        - Pade approximation of time delays.
% 
%  State-space models.
%    rss,drss    - Random stable state-space models.
%    ss2ss       - State coordinate transformation.
%    canon       - State-space canonical forms.
%    ctrb, obsv  - Controllability and observability matrices.
%    gram        - Controllability and observability gramians.
%    ssbal       - Diagonal balancing of state-space realizations.  
%    balreal     - Gramian-based input/output balancing.
%    modred      - Model state reduction.
%    minreal     - Minimal realization and pole/zero cancellation.
%    sminreal    - Structurally minimal realization.
% 
%  Time response.
%    ltiview     - Response analysis GUI (LTI Viewer).
%    step        - Step response.
%    impulse     - Impulse response.
%    initial     - Response of state-space system with given initial state.
%    lsim        - Response to arbitrary inputs.
%    gensig      - Generate input signal for LSIM.
%    stepfun     - Generate unit-step input.
% 
%  Frequency response.
%    ltiview     - Response analysis GUI (LTI Viewer).
%    bode        - Bode plot of the frequency response.
%    sigma       - Singular value frequency plot.
%    nyquist     - Nyquist plot.
%    nichols     - Nichols chart.
%    margin      - Gain and phase margins.
%    freqresp    - Frequency response over a frequency grid.
%    evalfr      - Evaluate frequency response at given frequency.
% 
%  System interconnections.
%    append      - Group LTI systems by appending inputs and outputs.
%    parallel    - Generalized parallel connection (

function Readme
%MATLAB Tour Partial Function Help:  cont_con
%
%  Release Notes for the Control System Toolbox.
%  Version 4.2   04-Sep-1998
% 
%  This file contains a list of enhancements and new features in the
%  Control System Toolbox since version 4.2.  
% 
%  NEW FEATURES
% 
%    "Symbolic" specification of transfer functions - 
%       To create the transfer function H(s) = (s+2)/(s^2+3s+1),
%       you can now directly type
%          s = tf('s')   % Laplace variable s
%          H = (s+2)/(s^2+3*s+1)
%       The same applies to ZPK models.
% 
%    Frequency Response Data (FRD) object - This new addition to the
%       LTI object family provides a convenient way to manipulate and 
%       analyze frequency response functions and experimental frequency 
%       response data.
% 
%    Arrays of LTI models - LTI arrays allow you to manipulate a  
%       collection of TF, SS, ZPK, or FRD models as a single MATLAB   
%       variable.  LTI arrays are an extension of single LTI models
%       that enable batch analysis of entire sets of models.  Most
%       operations and functions support LTI arrays and are applied 
%       to each model in the array in a vectorized fashion.
% 
%    Extensive support of time delays - You can now specify independent 
%       time delays for each I/O pair of a MIMO model using the 
%       "ioDelayMatrix" property.  You can also use the "InputDelay" and
%       "OuputDelay" properties to specify only input or output delays 
%       (useful for state-space models).  In addition, time delays are 
%       now fully supported for discrete-time models as long as they are 
%       integer multiples of the sampling time.  The property "Td" is 
%       grandfathered and superseded by "InputDelay."
% 
%    Improved algorithm for minimal state-space realization computation - 
%       The MINREAL command uses a new, more robust algorithm.  You can
%       also use the new command SMINREAL to remove states that are not
%       connected to the input(s) or output(s).
%          
%    New LTI properties "InputGroup" and "OutputGroup" - 
%       These properties allow you to specify different categories
%       (groups) of input or output channels, and to attach names to
%       these groups.  For instance, you can group the inputs 1 and 3
%       into a group labeled 'noise'.  You can then refer collectively
%       to these input channels by the name 'noise', as in 
%          sys(:,'noise')
% 
%  ENHANCEMENTS
% 
%    LTI Viewer Version 2 -
%       The new LTI Viewer allows you to analyze up to six different 
%       response plots on a single Viewer. Each response contains its
%       own set of Viewer Controls, accessed by right-clicking in any
%       response axes. The Viewer Configuration tool, available from
%       the Viewer's Tools menu, allows you to change the number 
%       and type of responses contained in the Viewer.
% 
%    Simulink LTI Viewer - 
%       The Simulink LTI Viewer can now linearize Simulink models
%       containing discrete states. The linearization routine generates
%       a discrete LTI object with a sample time which is the least 
%       common multiple of all the sample times in the Simulink model.
%       In addition, the Input and Output Point blocks can now be dropped
%       on vectorized signal lines in the Simulink diagram.
%       
% 
%  ----------------------------------------------------------------------
%  README file for the Control System Toolbox.
%  Version 4.1   05-Dec-1997
% 
%  This file contains a list of enhancements and new features in the
%  Control System Toolbox since version 4.0.  
% 
%  NEW FEATURES
% 
%    RLTOOL - Graphical user interface (GUI) for Root Locus Design.
% 
%    Simulink LTI Viewer - Linear analysis tool for Simulink diagrams.
%       To open this tool, select Linear Analysis in the Tools menu
%       of your Simulink diagram.
% 
%  ENHANCEMENTS
% 
%    1) Sharper root locus plots
%    2) Export option in the LTI Viewer
% 
%  ----------------------------------------------------------------------
%  README file for the Control System Toolbox.
%  Version 4.0  15-Nov-1996
%  
%  NEW FEATURES
%  
%    LTI objects - specialized data structures to represent transfer 
%       functions, zero-pole-gain models, or state-space models.
%       See the HELP for TF, ZPK, SS, and LTIPROPS for more details.
% 
%    Overloaded operations on LTI objects - you can now use +, *, [],...
%       to manipulate and interconnect LTI models.
%    
%    LTIVIEW - graphical user interface for linear system analysis.
% 
%    STEP, BODE, ... - now handle MIMO system responses and allow you
%       to compare the responses of several systems.
% 
%    CARE, DARE - enhanced continuous and discrete Riccati equation 
%       solvers.
% 
%    KALMAN - Kalman estimator synthesis.
% 
%    MILLDEMO - new demonstration of LQG synthesis tools.
% 
%  Use HELP on these files or TYPE them for more information.

function tf
%MATLAB Tour Partial Function Help:  cont_con
%
% TF  Creation of transfer functions or conversion to transfer function.
% 
%   Creation:
%     SYS = TF(NUM,DEN) creates a continuous-time transfer function SYS with 
%     numerator(s) NUM and denominator(s) DEN.  The output SYS is a TF object.  
% 
%     SYS = TF(NUM,DEN,TS) creates a discrete-time transfer function with
%     sample time TS (set TS=-1 if the sample time is undetermined).
% 
%     S = TF('s') specifies the transfer function H(s) = s (Laplace variable).
%     Z = TF('z',TS) specifies H(z) = z with sample time TS.
%     You can then specify transfer functions directly as rational expressions 
%     in S or Z, e.g.,
%        s = tf('s');  H = (s+1)/(s^2+3*s+1)
% 
%     SYS = TF creates an empty TF object.
%     SYS = TF(M) specifies a static gain matrix M.
% 
%     In all syntax above, the input list can be followed by pairs
%        'PropertyName1', PropertyValue1, ...
%     that set the various properties of TF models (type LTIPROPS for details).  
%     To make SYS inherit all its LTI properties from an existing LTI model
%     REFSYS, use the syntax SYS = TF(NUM,DEN,REFSYS).
% 
%   Data format:
%     For SISO models, NUM and DEN are row vectors listing the numerator and
%     denominator coefficients in 
%      * descending powers of s or z by default
%      * ascending powers of q = z^-1 if the 'Variable' property is set to  
%        'z^-1' or 'q' (DSP convention).
% 
%     For MIMO models with NY outputs and NU inputs, NUM and DEN are NY-by-NU
%     cell arrays of row vectors where NUM{i,j} and DEN{i,j} specify the 
%     transfer function from input j to output i.  For example,
%        H = TF( {-5 ; [1 -5 6]} , {[1 -1] ; [1 1 0]})
%     specifies the two-output, one-input transfer function
%        [     -5 /(s-1)      ]
%        [ (s^2-5s+6)/(s^2+s) ] 
% 
%     By default, transfer functions are displayed as functions of 's' or 'z'.
%     Alternatively, you can set the variable name to 'p' (continuous time) 
%     and 'z^-1' or 'q' (discrete time) by modifying the 'Variable' property.
% 
%   Arrays of transfer functions:
%     You can create arrays of transfer functions by using ND cell arrays for
%     NUM and DEN above.  For example, if NUM and DEN are cell arrays of size
%     [NY NU 3 4], then 
%        SYS = TF(NUM,DEN) 
%     creates the 3-by-4 array of transfer functions
%        SYS(:,:,k,m) = TF(NUM(:,:,k,m),DEN(:,:,k,m)),  k=1:3,  m=1:4.
%     Each of these transfer functions has NY outputs and NU inputs.
% 
%     To pre-allocate an array of zero transfer functions with NY outputs
%     and NU inputs, use the syntax
%        SYS = TF(ZEROS([NY NU k1 k2...])) .
% 
%   Conversion:
%     SYS = TF(SYS) converts an arbitrary LTI model SYS to the transfer 
%     function representation. The result is a TF object.  
% 
%     SYS = TF(SYS,'inv') uses a fast algorithm for conversion from state
%     space to TF, but is typically less accurate for high-order systems.
% 
%   

function zpk
%MATLAB Tour Partial Function Help:  cont_con
%
% ZPK  Create zero-pole-gain models or convert to zero-pole-gain format.
% 
%   Creation:
%     SYS = ZPK(Z,P,K) creates a continuous-time zero-pole-gain (ZPK) 
%     model SYS with zeros Z, poles P, and gains K.  The output SYS is 
%     a ZPK object.  
% 
%     SYS = ZPK(Z,P,K,Ts) creates a discrete-time ZPK model with sample
%     time Ts (set Ts=-1 if the sample time is undetermined).
% 
%     S = ZPK('s') specifies H(s) = s (Laplace variable).
%     Z = ZPK('z',TS) specifies H(z) = z with sample time TS.
%     You can then specify ZPK models directly as rational expressions in 
%     S or Z, e.g.,
%        z = zpk('z',0.1);  H = (z+.1)*(z+.2)/(z^2+.6*z+.09)
% 
%     SYS = ZPK creates an empty zero-pole-gain model.
%     SYS = ZPK(D) specifies a static gain matrix D.
% 
%     In all syntax above, the input list can be followed by pairs
%        'PropertyName1', PropertyValue1, ...
%     that set the various properties of ZPK models (type LTIPROPS for 
%     details).  To make SYS inherit all its LTI properties from an 
%     existing LTI model REFSYS, use the syntax SYS = ZPK(Z,P,K,REFSYS).
% 
%   Data format:
%     For SISO models, Z and P are the vectors of zeros and poles (set  
%     Z=[] if no zeros) and K is the scalar gain.
% 
%     For MIMO systems with NY outputs and NU inputs, 
%       * Z and P are NY-by-NU cell arrays where Z{i,j} and P{i,j}  
%         specify the zeros and poles of the transfer function from
%         input j to output i
%       * K is the 2D matrix of gains for each I/O channel.  
%     For example,
%        H = ZPK( {[];[2 3]} , {1;[0 -1]} , [-5;1] )
%     specifies the two-output, one-input ZPK model
%        [    -5 /(s-1)      ]
%        [ (s-2)(s-3)/s(s+1) ] 
% 
%   Arrays of zero-pole-gain models:
%     You can create arrays of ZPK models by using ND cell arrays for Z,P 
%     above, and an ND array for K.  For example, if Z,P,K are 3D arrays 
%     of size [NY NU 5], then 
%        SYS = ZPK(Z,P,K) 
%     creates the 5-by-1 array of ZPK models
%        SYS(:,:,m) = ZPK(Z(:,:,m),P(:,:,m),K(:,:,m)),   m=1:5.
%     Each of these models has NY outputs and NU inputs.
% 
%     To pre-allocate an array of zero ZPK models with NY outputs and NU 
%     inputs, use the syntax
%        SYS = ZPK(ZEROS([NY NU k1 k2...])) .
% 
%   Conversion:
%     SYS = ZPK(SYS) converts an arbitrary LTI model SYS to the ZPK 
%     representation. The result is a ZPK object.  
% 
%     SYS = ZPK(SYS,'inv') uses a fast algorithm for conversion from state
%     space to ZPK, but is typically less accurate for high-order systems.
% 
%   

function ss
%MATLAB Tour Partial Function Help:  cont_con
%
% SS  Create state-space model or convert LTI model to state space.
%        
%   Creation:
%     SYS = SS(A,B,C,D) creates a continuous-time state-space (SS) model 
%     SYS with matrices A,B,C,D.  The output SYS is a SS object.  You 
%     can set D=0 to mean the zero matrix of appropriate dimensions.
% 
%     SYS = SS(A,B,C,D,Ts) creates a discrete-time SS model with sample 
%     time Ts (set Ts=-1 if the sample time is undetermined).
% 
%     SYS = SS creates an empty SS object.
%     SYS = SS(D) specifies a static gain matrix D.
% 
%     In all syntax above, the input list can be followed by pairs
%        'PropertyName1', PropertyValue1, ...
%     that set the various properties of SS models (type LTIPROPS for 
%     details).  To make SYS inherit all its LTI properties from an  
%     existing LTI model REFSYS, use the syntax SYS = SS(A,B,C,D,REFSYS).
% 
%   Arrays of state-space models:
%     You can create arrays of state-space models by using ND arrays for
%     A,B,C,D above.  The first two dimensions of A,B,C,D determine the 
%     number of states, inputs, and outputs, while the remaining 
%     dimensions specify the array sizes.  For example, if A,B,C,D are  
%     4D arrays and their last two dimensions have lengths 2 and 5, then 
%        SYS = SS(A,B,C,D)
%     creates the 2-by-5 array of SS models 
%        SYS(:,:,k,m) = SS(A(:,:,k,m),...,D(:,:,k,m)),  k=1:2,  m=1:5.
%     All models in the resulting SS array share the same number of 
%     outputs, inputs, and states.
% 
%     SYS = SS(ZEROS([NY NU S1...Sk])) pre-allocates space for an SS array 
%     with NY outputs, NU inputs, and array sizes [S1...Sk].
% 
%   Conversion:
%     SYS = SS(SYS) converts an arbitrary LTI model SYS to state space,
%     i.e., computes a state-space realization of SYS.
% 
%     SYS = SS(SYS,'min') computes a minimal realization of SYS.
% 
%   

function dss
%MATLAB Tour Partial Function Help:  cont_con
%
% DSS  Create descriptor state-space (DSS) models
%           .
%         E x = A x + B u            E x[n+1] = A x[n] + B u[n]
%                              or 
%           y = C x + D u                y[n] = C x[n] + D u[n]  
%          
%    SYS = DSS(A,B,C,D,E) creates a continuous-time DSS model SYS
%    with matrices A,B,C,D,E.  The output SYS is a SS object.  You 
%    can set D=0 to mean the zero matrix of appropriate dimensions.
% 
%    SYS = DSS(A,B,C,D,E,Ts) creates a discrete-time DSS model with 
%    sample time Ts (set Ts=-1 if the sample time is undetermined).
% 
%    In both syntax, the input list can be followed by pairs
%       'PropertyName1', PropertyValue1, ...
%    that set the various properties of SS models (see LTIPROPS for 
%    details).  To make SYS inherit all its LTI properties from an  
%    existing LTI model REFSYS, use the syntax 
%       SYS = DSS(A,B,C,D,E,REFSYS).
% 
%    You can create arrays of DSS models by using ND arrays for 
%    A,B,C,D,E.  See help for SS for more details.
% 
%    

function frd
%MATLAB Tour Partial Function Help:  cont_con
%
% FRD  Creation of or conversion to Frequency Response Data model.
% 
%    Frequency Response Data (FRD) models are useful for storing frequency
%    responses of LTI systems, including experimental response data.
% 
%   Creation:
%     SYS = FRD(RESPONSE,FREQS) creates an FRD model SYS with response data
%     in RESPONSE at frequency points in FREQS.  The output SYS is an FRD model.
%     See "Data format" below for details.
% 
%     SYS = FRD(RESPONSE,FREQS,TS) creates a discrete-time FRD model with
%     sample time TS (set TS = -1 if the sample time is undetermined).
% 
%     SYS = FRD creates an empty FRD model.
% 
%     In all syntax above, the input list can be followed by pairs
%        'PropertyName1', PropertyValue1, ...
%     that set the various properties of FRD models (type LTIPROPS for details).  
%     To make SYS inherit all its LTI properties from an existing LTI model
%     REFSYS, use the syntax SYS = FRD(RESPONSE,FREQS,REFSYS).
% 
%   Data format:
%     For SISO models, FREQS is a vector of real frequencies, and RESPONSE is
%     a vector of response data, where RESPONSE(i) represents the system
%     response at FREQS(i).
% 
%     For MIMO FRD models with NY outputs, NU inputs, and NF frequency points,
%     RESPONSE is a NY-by-NU-by-NF array where RESPONSE(i,j,k) specifies the
%     frequency response from input j to output i at frequency FREQS(k).
% 
%     By default, the units of the frequencies in FREQS are 'rad/s'.
%     Alternately, you can change the units to 'Hz' by modifying the 'Units'
%     property.  Note that changing this property value does not
%     change the numerical frequency values.  Use CHGUNITS(SYS,UNITS) to change
%     the frequency units of an FRD model, performing the necessary conversion.
% 
%   Arrays of FRD models:
%     You can create arrays of FRD models by using an ND array for RESPONSE
%     above.  For example, if RESPONSE is an array of size [NY NU NF 3 4], then 
%        SYS = FRD(RESPONSE,FREQS) 
%     creates the 3-by-4 array of FRD models, where
%        SYS(:,:,k,m) = FRD(RESPONSE(:,:,:,k,m),FREQS),  k=1:3,  m=1:4.
%     Each of these FRD models has NY outputs and NU inputs, and holds data at
%     each frequency point in FREQS.
% 
%   Conversion:
%     SYS = FRD(SYS,FREQS,'Units',UNITS) converts an arbitrary LTI model SYS to
%     the FRD model representation, generating the system response at each
%     frequency in FREQS.  UNITS specifies the units of the frequencies in FREQS,
%     which may be 'rad/s' or 'Hz', and will default to 'rad/s' if the last
%     two arguments are omitted.  The result is an FRD model.
% 
%   

function filt
%MATLAB Tour Partial Function Help:  cont_con
%
% FILT  DSP-oriented specification of discrete transfer functions.
% 
%    SYS = FILT(NUM,DEN)      Digital filter H(z^-1)=NUM(z^-1)./DEN(z^-1) 
%                             with unspecified sampling time.
%    SYS = FILT(NUM,DEN,Ts)   Digital filter H(z^-1)=NUM(z^-1)./DEN(z^-1)
%                             with sample time Ts.
%    SYS = FILT(M)            Gain matrix.
% 
%    All the above calling syntaxes may be followed by Property/Value pairs. 
% 
%    In the SISO case, NUM and DEN are row vectors listing the numerator and
%    denominator coefficients in ascending powers of z^-1.  In the MIMO case,
%    NUM and DEN are cell arrays of row vectors such that NUM{i,j} and 
%    DEN{i,j} specify the transfer function from input j to output i.
% 
%    

function set
%MATLAB Tour Partial Function Help:  cont_con
%
% SET    Set object properties.
%    SET(H,'PropertyName',PropertyValue) sets the value of the
%    specified property for the graphics object with handle H.
%    H can be a vector of handles, in which case SET sets the
%    properties' values for all the objects.
% 
%    SET(H,a) where a is a structure whose field names are object
%    property names, sets the properties named in each field name
%    with the values contained in the structure.
% 
%    SET(H,pn,pv) sets the named properties specified in the cell array
%    of strings pn to the corresponding values in the cell array pv for
%    all objects specified in H.  The cell array pn must be 1-by-N, but
%    the cell array pv can be M-by-N where M is equal to length(H) so 
%    that each object will be updated with a different set of values
%    for the list of property names contained in pn.
% 
%    SET(H,'PropertyName1',PropertyValue1,'PropertyName2',PropertyValue2,...)
%    sets multiple property values with a single statement.  Note that it
%    is permissible to use property/value string pairs, structures, and
%    property/value cell array pairs in the same call to SET.
% 
%    A = SET(H, 'PropertyName') 
%    SET(H,'PropertyName')
%    returns or displays the possible values for the specified
%    property of the object with handle H.  The returned array is
%    a cell array of possible value strings or an empty cell array
%    if the property does not have a finite set of possible string
%    values.
%    
%    A = SET(H) 
%    SET(H) 
%    returns or displays all property names and their possible values for
%    the object with handle H.  The return value is a structure whose
%    field names are the property names of H, and whose values are 
%    cell arrays of possible property values or empty cell arrays.
% 
%    The default value for an object property can be set on any of an 
%    object's ancestors by setting the PropertyName formed by
%    concatenating the string 'Default', the object type, and the 
%    property name.  For example, to set the default color of text objects
%    to red in the current figure window:
% 
%       set(gcf,'DefaultTextColor','red')
%    
%    Defaults can not be set on a descendant of the object, or on the
%    object itself - for example, a value for 'DefaultAxesColor' can not
%    be set on an axes or an axes child, but can be set on a figure or on
%    the root.
% 
%    Three strings have special meaning for PropertyValues:
%      'default' - use default value (from nearest ancestor)
%      'factory' - use factory default value
%      'remove'  - remove default value.
% 
%    

function ltimodels
%MATLAB Tour Partial Function Help:  cont_con
%
% LTIMODELS  Help on LTI models.
% 
%    LTIMODELS gives general information on the various types of 
%    LTI models supported in the Control System Toolbox.
% 
%    LTIMODELS(MODELTYPE) gives additional details and examples 
%    for each type of LTI model.  The string MODELTYPE selects
%    the model type among the following:
%       'tf'  :   transfer functions (TF objects)
%       'zpk' :   zero-pole-gain models (ZPK objects)
%       'ss'  :   state-space models (SS objects)
%       'frd' :   frequency response data models (FRD objects).
% 
%    Note that you can type
%       ltimodels zpk
%    as a shorthand for
%       ltimodels('zpk') .
% 
%    

function ltiprops
%MATLAB Tour Partial Function Help:  cont_con
%
% LTIPROPS  Help on LTI model properties.
% 
%    LTIPROPS gives details on the generic properties of LTI models.
% 
%    LTIPROPS(MODELTYPE) gives details on the properties specific
%    to the various types of LTI models.  The string MODELTYPE 
%    selects the model type among the following:
%       'tf'  :   transfer functions (TF objects)
%       'zpk' :   zero-pole-gain models (ZPK objects)
%       'ss'  :   state-space models (SS objects)
%       'frd' :   frequency response data (FRD objects).
% 
%    Note that you can type
%       ltiprops tf
%    as a shorthand for
%       ltiprops('tf') .
% 
%    

function tfdata
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/tfdata.m ---
%
% TFDATA  Quick access to transfer function data.
% 
%    [NUM,DEN] = TFDATA(SYS) returns the numerator(s) and denominator(s) 
%    of the transfer function SYS.  For a transfer function with NY 
%    outputs and NU inputs, NUM and DEN are NY-by-NU cell arrays where
%    the (I,J) entry specifies the transfer function from input J to 
%    output I.  SYS is first converted to transfer function if necessary.
% 
%    [NUM,DEN,TS] = TFDATA(SYS) also returns the sample time TS.  Other
%    properties of SYS can be accessed with GET or by direct structure-like 
%    referencing (e.g., SYS.Ts)
% 
%    For a single SISO model SYS, the syntax
%        [NUM,DEN] = TFDATA(SYS,'v')
%    returns the numerator and denominator as row vectors rather than
%    cell arrays.
% 
%    For arrays SYS of LTI models, NUM and DEN are ND cell arrays with
%    the same sizes as SYS, and such that NUM(:,:,k) and DEN(:,:,k) 
%    specify the transfer function of the k-th model SYS(:,:,k).
% 
%    

function zpkdata
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/zpkdata.m ---
%
% ZPKDATA  Quick access to zero-pole-gain data.
% 
%    [Z,P,K] = ZPKDATA(SYS) returns the zeros, poles, and gain for
%    each I/O channel of the LTI model SYS.  The cell arrays Z,P 
%    and the matrix K have as many rows as outputs and as many columns 
%    as inputs, and their (I,J) entries specify the zeros, poles, 
%    and gain of the transfer function from input J to output I.  
%    SYS is first converted to zero-pole-gain format if necessary.
% 
%    [Z,P,K,TS] = ZPKDATA(SYS)  also returns the sample time TS. 
%    Other properties of SYS can be accessed with GET or by direct 
%    structure-like referencing (e.g., SYS.Ts)
% 
%    For a single SISO model SYS, the syntax
%        [Z,P,K] = ZPKDATA(SYS,'v')
%    returns the zeros Z and poles P as column vectors rather than
%    cell arrays.       
% 
%    For arrays SYS of LTI models, Z,P,K are arrays of the same size as
%    SYS such that the ZPK representation of the m-th model SYS(:,:,m)
%    is Z(:,:,m), P(:,:,m), K(:,:,m).
% 
%    

function ssdata
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/ssdata.m ---
%
% SSDATA  Quick access to state-space data.
% 
%    [A,B,C,D] = SSDATA(SYS) retrieves the matrix data A,B,C,D
%    for the state-space model SYS.  If SYS is not a state-space 
%    model, it is first converted to the state-space representation.
% 
%    [A,B,C,D,TS] = SSDATA(SYS) also returns the sample time TS.
%    Other properties of SYS can be accessed with GET or by direct 
%    structure-like referencing (e.g., SYS.Ts).
% 
%    For arrays of LTI models with the same order (number of states),
%    A,B,C,D are multi-dimensional arrays where A(:,:,k), B(:,:,k), 
%    C(:,:,k), D(:,:,k) give the state-space matrices of the 
%    k-th model SYS(:,:,k).
% 
%    For arrays of LTI models with variable order, use the syntax
%       [A,B,C,D] = SSDATA(SYS,'cell')
%    to return the variable-size A,B,C matrices into cell arrays. 
% 
%    

function dssdata
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/dssdata.m ---
%
% DSSDATA  Quick access to descriptor state-space data.
% 
%    [A,B,C,D,E] = DSSDATA(SYS) returns the values of the A,B,C,D,E
%    matrices for the descriptor state-space model SYS (see DSS).  
%    DSSDATA is equivalent to SSDATA for regular state-space models
%    (i.e., when E=I).
% 
%    [A,B,C,D,E,TS] = DSSDATA(SYS) also returns the sample time TS.
%    Other properties of SYS can be accessed with GET or by direct 
%    structure-like referencing (e.g., SYS.Ts).
% 
%    For arrays of LTI models with variable order, use the syntax
%       [A,B,C,D,E] = DSSDATA(SYS,'cell')
%    to return the variable-size A,B,C,E matrices into cell arrays. 
% 
%    

function frdata
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/frdata.m ---
%
% FRDATA  Quick access to frequency response data.
% 
%    [RESPONSE,FREQ] = FRDATA(SYS) returns the response data and
%    frequency samples of the frequency response data (FRD) model SYS.
% 
%    For a single model SYS with Ny outputs and Nu inputs, at Nw frequencies,
%    RESPONSE is a Ny-by-Nu-by-Nw array where the (I,J,K) element specifies
%    the response from input J to output I at frequency FREQ(K).  FREQ
%    is a column vector of length Nw which contains the frequency
%    samples of the FRD.
% 
%    [RESPONSE,FREQ,TS] = FRDATA(SYS) also returns the sample time TS.  Other
%    properties of SYS can be accessed with GET or by direct structure-like 
%    referencing (e.g., SYS.Ts)
% 
%    For a single SISO model SYS, the syntax
%        [RESPONSE,FREQ] = FRDATA(SYS,'v')
%    returns the RESPONSE as a column vector rather than a
%    3-dimensional array.
% 
%    For an S1-by-S2-...-by-Sn array SYS of FRD models, each with Ny outputs
%    and Nu inputs at Nw frequency points, RESPONSE is an array of size
%    [Ny Nu Nw S1 S2 ... Sn], where RESPONSE(:,:,K,p1,p2,...,pn)
%    specifies the reponse of the model SYS(:,:,p1,p2,...,pn) at frequency
%    FREQ(K).
% 
%    

function get
%MATLAB Tour Partial Function Help:  cont_con
%
% GET    Get object properties.
%    V = GET(H,'PropertyName') returns the value of the specified
%    property for the graphics object with handle H.  If H is a 
%    vector of handles, then get will return an M-by-1 cell array
%    of values where M is equal to length(H).  If 'PropertyName' is
%    replaced by a 1-by-N or N-by-1 cell array of strings containing
%    property names, then GET will return an M-by-N cell array of
%    values.
% 
%    GET(H) displays all property names and their current values for
%    the graphics object with handle H.
% 
%    V = GET(H) where H is a scalar, returns a structure where each
%    field name is the name of a property of H and each field contains
%    the value of that property.
% 
%    V = GET(0, 'Factory') 
%    V = GET(0, 'Factory<ObjectType>')
%    V = GET(0, 'Factory<ObjectType><PropertyName>') 
%    returns for all object types the factory values of all properties
%    which have user-settable default values.  
% 
%    V = GET(H, 'Default') 
%    V = GET(H, 'Default<ObjectType>') 
%    V = GET(H, 'Default<ObjectType><PropertyName>') 
%    returns information about default property values (H must be
%    scalar).  'Default' returns a list of all default property values
%    currently set on H.  'Default<ObjectType>' returns only the
%    defaults for properties of <ObjectType> set on H.
%    'Default<ObjectType><PropertyName>' returns the default value
%    for the specific property, by searching the defaults set on H
%    and its ancestors, until that default is found.  If no default
%    value for this property has been set on H or any ancestor of H
%    up through the root, then the factory value for that property
%    is returned.
%  
%    Defaults can not be queried on a descendant of the object, or on the
%    object itself - for example, a value for 'DefaultAxesColor' can not
%    be queried on an axes or an axes child, but can be queried on a figure
%    or on the root.
% 
%    When using the 'Factory' or 'Default' GET, if PropertyName is 
%    omitted then the return value will take the form of a
%    structure in which each field name is a property name and the 
%    corresponding value is the value of that property.  If 
%    PropertyName is specified then a matrix or string value will be
%    returned.
%    
% 
%    

function class
%MATLAB Tour Partial Function Help:  cont_con
%
% CLASS  Create object or return object class.
%    CLASS(OBJ) returns the class of the object OBJ.
%    Possibilities are:
%      double       -- double precision floating point number array
%                      (this is the traditional MATLAB matrix or array)
%      sparse       -- 2-D real (or complex) sparse matrix
%      struct       -- Structure array
%      cell         -- cell array
%      char         -- Character array
%      <class_name> -- Custom object class
% 
%    Within a constructor method, CLASS(S,'class_name') creates an
%    object of class 'class_name' from the structure S.  This
%    syntax is only valid in a function named <class_name>.m in a
%    directory named @<class_name> (where <class_name> is the same
%    as the string passed into CLASS).  On VMS, the method directory
%    has the name #<class_name>.
% 
%    CLASS(S,'class_name',PARENT1,PARENT2,...) also inherits the
%    methods and fields of the parent objects PARENT1, PARENT2, ...
% 
%    

function isa
%MATLAB Tour Partial Function Help:  cont_con
%
% ISA    True if object is a given class.
%    ISA(OBJ,'class_name') returns 1 if OBJ is of class (or
%    subclass) of 'class_name' and 0 otherwise.
% 
%    Some possibilities for 'class_name' are:
%      double       -- Double precision floating point number array
%                      (this is the traditional MATLAB matrix or array)
%      sparse       -- 2-D real (or complex) sparse matrix
%      struct       -- Structure array
%      cell         -- Cell array
%      char         -- Character array
%      uint8        -- Unsigned 8-bit integer array
%      <class_name> -- Custom object class
% 
%    

function size
%MATLAB Tour Partial Function Help:  cont_con
%
% SIZE   Size of matrix.  
%    D = SIZE(X), for M-by-N matrix X, returns the two-element
%    row vector D = [M, N] containing the number of rows and columns
%    in the matrix.  For N-D arrays, SIZE(X) returns a 1-by-N
%    vector of dimension lengths.  Trailing singleton dimensions
%    are ignored.
% 
%    [M,N] = SIZE(X) returns the number of rows and columns in
%    separate output variables. [M1,M2,M3,...,MN] = SIZE(X)
%    returns the length of the first N dimensions of X.
% 
%    M = SIZE(X,DIM) returns the length of the dimension specified
%    by the scalar DIM.  For example, SIZE(X,1) returns the number
%    of rows.
% 
%    

function ndims
%MATLAB Tour Partial Function Help:  cont_con
%
% NDIMS   Number of dimensions.
%    N = NDIMS(X) returns the number of dimensions in the array X.
%    The number of dimensions in an array is always greater than
%    or equal to 2.  Trailing singleton dimensions are ignored.
%    Put simply, it is LENGTH(SIZE(X)).
% 
%    

function isempty
%MATLAB Tour Partial Function Help:  cont_con
%
% ISEMPTY True for empty matrix.
%    ISEMPTY(X) returns 1 if X is an empty array and 0 otherwise. An
%    empty array has no elements, that is prod(size(X))==0.
%
% Overloaded methods
%    help lti/isempty.m
%    help frd/isempty.m
%    help activex/isempty.m

function isct
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/isct.m ---
%
% ISCT  True for continuous-time LTI models.
% 
%    ISCT(SYS) returns 1 (true) if the LTI model SYS is continuous
%    (zero sampling time), and 0 (false) otherwise.
% 
%    

function isdt
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for ss/isdt.m ---
%
% ISDT  Check if LTI model is discrete time.
% 
%    ISDT(SYS) returns 1 (true) if the LTI model SYS is 
%    discrete, 0 (false) otherwise.  ISDT always returns 1 
%    for empty systems or static gains.
% 
%    

function isproper
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for ss/isproper.m ---
%
% ISPROPER  True for proper LTI systems.
% 
%    ISPROPER(SYS) returns 1 (true) if the LTI model SYS is proper 
%    (relative degree<=0), and 0 (false) otherwise.  If SYS is an
%    array of LTI models, ISPROPER(SYS) is true if all models are
%    proper.
% 
%    

function issiso
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/issiso.m ---
%
% ISSISO  True for SISO LTI models.
% 
%    ISSISO(SYS) returns 1 (true) if SYS is a single-input,
%    single-output (SISO) model or array of models, and
%    0 (false) otherwise.
% 
%    

function reshape
%MATLAB Tour Partial Function Help:  cont_con
%
% RESHAPE Change size.
%    RESHAPE(X,M,N) returns the M-by-N matrix whose elements
%    are taken columnwise from X.  An error results if X does
%    not have M*N elements.
% 
%    RESHAPE(X,M,N,P,...) returns an N-D array with the same
%    elements as X but reshaped to have the size M-by-N-by-P-by-...
%    M*N*P*... must be the same as PROD(SIZE(X)).
% 
%    RESHAPE(X,[M N P ...]) is the same thing.
% 
%    In general, RESHAPE(X,SIZ) returns an N-D array with the same
%    elements as X but reshaped to the size SIZ.  PROD(SIZ) must be
%    the same as PROD(SIZE(X)). 
% 
%    

function chgunits
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/chgunits.m ---
%
% CHGUNITS  Change frequency units of an FRD model.
% 
%    SYS = CHGUNITS(SYS,UNITS) changes the units of the frequency
%    points stored in the FRD model SYS to UNITS, where UNITS
%    is either 'Hz or 'rad/s'.  A 2*pi scaling factor is applied
%    to the frequency values and the 'Units' property is updated.
%    If the 'Units' field already matches UNITS, no action is taken.
% 
%    

function c2d
%MATLAB Tour Partial Function Help:  cont_con
%
% C2D  Conversion of continuous-time models to discrete time.
% 
%    SYSD = C2D(SYSC,TS,METHOD) converts the continuous-time LTI 
%    model SYSC to a discrete-time model SYSD with sample time TS.  
%    The string METHOD selects the discretization method among the 
%    following:
%       'zoh'       Zero-order hold on the inputs.
%       'foh'       Linear interpolation of inputs (triangle appx.)
%       'tustin'    Bilinear (Tustin) approximation.
%       'prewarp'   Tustin approximation with frequency prewarping.  
%                   The critical frequency Wc is specified as fourth 
%                   input by C2D(SYSC,TS,'prewarp',Wc).
%       'matched'   Matched pole-zero method (for SISO systems only).
%    The default is 'zoh' when METHOD is omitted.
% 
%    For state-space models SYS and the 'zoh' or 'foh' methods,
%       [SYSD,G] = C2D(SYSC,TS,METHOD)
%    also returns a matrix G that maps continuous initial conditions
%    into discrete initial conditions.  Specifically, if x0,u0 are
%    initial states and inputs for SYSC, then equivalent initial
%    conditions for SYSD are given by
%       xd0 = G * [x0;u0],     ud0 = u0 .
% 
%    

function d2c
%MATLAB Tour Partial Function Help:  cont_con
%
% D2C  Conversion of discrete LTI models to continuous time.
% 
%    SYSC = D2C(SYSD,METHOD) produces a continuous-time model SYSC
%    that is equivalent to the discrete-time LTI model SYSD.  
%    The string METHOD selects the conversion method among the 
%    following:
%       'zoh'       Assumes zero-order hold on the inputs.
%       'tustin'    Bilinear (Tustin) approximation.
%       'prewarp'   Tustin approximation with frequency prewarping.  
%                   The critical frequency Wc is specified last as in
%                   D2C(SysD,'prewarp',Wc)
%       'matched'   Matched pole-zero method (for SISO systems only).
%    The default is 'zoh' when METHOD is omitted.
% 
%    

function d2d
%MATLAB Tour Partial Function Help:  cont_con
%
% D2D  Resample discrete LTI system.
% 
%    SYS = D2D(SYS,TS) resamples the discrete-time LTI model SYS 
%    to produce an equivalent discrete system with sample time TS.
% 
%    

function and
%MATLAB Tour Partial Function Help:  cont_con
%
% &  Logical AND.
%    A & B is a matrix whose elements are 1's where both A and B
%    have non-zero elements, and 0's where either has a zero element.
%    A and B must have the same dimensions unless one is a scalar.
% 
%    C = AND(A,B) is called for the syntax 'A & B' when A or B is an
%    object.

function stack
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/stack.m ---
%
% STACK  Stack LTI models into LTI array.
% 
%    SYS = STACK(ARRAYDIM,SYS1,SYS2,...) produces an array of LTI
%    models SYS by stacking the LTI models SYS1,SYS2,... along
%    the array dimension ARRAYDIM.  All models must have the same 
%    number of inputs and outputs, and the I/O dimensions are not
%    counted as array dimensions.
% 
%    For example, if SYS1 and SYS2 are two LTI models with the 
%    same I/O dimensions,
%      * STACK(1,SYS1,SYS2) produces a 2-by-1 LTI array
%      * STACK(2,SYS1,SYS2) produces a 1-by-2 LTI array
%      * STACK(3,SYS1,SYS2) produces a 1-by-1-by-2 LTI array.
% 
%    You can also use STACK to concatenate LTI arrays SYS1,SYS2,...
%    along some array dimension ARRAYDIM.
% 
%    

function inv
%MATLAB Tour Partial Function Help:  cont_con
%
% INV    Matrix inverse.
%    INV(X) is the inverse of the square matrix X.
%    A warning message is printed if X is badly scaled or
%    nearly singular.
% 
%    

function zero
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for ss/zero.m ---
%
% ZERO  Transmission zeros of LTI systems.
%  
%    Z = ZERO(SYS) returns the transmission zeros of the LTI 
%    model SYS.
% 
%    [Z,GAIN] = ZERO(SYS) also returns the transfer function gain
%    (in the zero-pole-gain sense) for SISO models SYS.
%    
%    If SYS is an array of LTI models with sizes [NY NU S1 ... Sp],
%    Z and K are arrays with as many dimensions as SYS such that 
%    Z(:,1,j1,...,jp) and K(1,1,j1,...,jp) give the zeros and gain 
%    of the LTI model SYS(:,:,j1,...,jp).  The vectors of zeros are 
%    padded with NaN values for models with relatively fewer zeros.
% 
%    

function pzmap
%MATLAB Tour Partial Function Help:  cont_con
%
% PZMAP  Pole-zero map of LTI models.
% 
%    PZMAP(SYS) computes the poles and (transmission) zeros of the
%    LTI model SYS and plots them in the complex plane.  The poles 
%    are plotted as x's and the zeros are plotted as o's.  
% 
%    When invoked with left-hand arguments,
%       [P,Z] = PZMAP(SYS)
%    returns the poles and zeros of the system in the column vectors 
%    P and Z.  No plot is drawn on the screen.  
% 
%    The functions SGRID or ZGRID can be used to plot lines of constant
%    damping ratio and natural frequency in the s or z plane.
% 
%    For arrays SYS of LTI models, PZMAP plots the poles and zeros of
%    each model in the array on the same diagram.
% 
%    

function dcgain
%MATLAB Tour Partial Function Help:  cont_con
%
% DCGAIN  DC gain of LTI models.
% 
%    K = DCGAIN(SYS) computes the steady-state (D.C. or low frequency)
%    gain of the LTI model SYS.
% 
%    If SYS is an array of LTI models with dimensions [NY NU S1 ... Sp],
%    DCGAIN returns an array K with the same dimensions such that
%       K(:,:,j1,...,jp) = DCGAIN(SYS(:,:,j1,...,jp)) .  
% 
%    

function norm
%MATLAB Tour Partial Function Help:  cont_con
%
% NORM   Matrix or vector norm.
%    For matrices...
%      NORM(X) is the largest singular value of X, max(svd(X)).
%      NORM(X,2) is the same as NORM(X).
%      NORM(X,1) is the 1-norm of X, the largest column sum,
%                      = max(sum(abs((X)))).
%      NORM(X,inf) is the infinity norm of X, the largest row sum,
%                      = max(sum(abs((X')))).
%      NORM(X,'fro') is the Frobenius norm, sqrt(sum(diag(X'*X))).
%      NORM(X,P) is available for matrix X only if P is 1, 2, inf or 'fro'.
% 
%    For vectors...
%      NORM(V,P) = sum(abs(V).^P)^(1/P).
%      NORM(V) = norm(V,2).
%      NORM(V,inf) = max(abs(V)).
%      NORM(V,-inf) = min(abs(V)).
% 
%    

function covar
%MATLAB Tour Partial Function Help:  cont_con
%
% COVAR  Covariance response of LTI models to white noise inputs.
% 
%    P = COVAR(SYS,W) computes the output response covariance 
%    P = E[yy'] when the LTI model SYS is driven by Gaussian 
%    white noise inputs. The noise intensity W is defined by
% 
%       E[w(t)w(tau)'] = W delta(t-tau)  (delta(t) = Dirac delta)
% 
%    in continuous time, and by
% 
%       E[w(k)w(n)'] = W delta(k,n)   (delta(k,n) = Kronecker delta)
% 
%    in discrete time.  Note that unstable systems or continuous-time 
%    models with non-zero feedthrough have infinite covariance response.
% 
%    [P,Q] = COVAR(SYS,W) also returns the state covariance Q = E[xx']
%    when SYS is a state-space model.
% 
%    If SYS is an array of LTI models with dimensions [NY NU S1 ... Sp], 
%    the array P has dimensions [NY NY S1 ... Sp] and
%       P(:,:,k1,...,kp) = COVAR(SYS(:,:,k1,...,kp)) .  
% 
%    

function damp
%MATLAB Tour Partial Function Help:  cont_con
%
% DAMP  Natural frequency and damping of LTI model poles.
% 
%     [Wn,Z] = DAMP(SYS) returns vectors Wn and Z containing the
%     natural frequencies and damping factors of the LTI model SYS.
%     For discrete-time models, the equivalent s-plane natural 
%     frequency and damping ratio of an eigenvalue lambda are:
%                
%        Wn = abs(log(lambda))/Ts ,   Z = -cos(angle(log(lambda))) .
% 
%     Wn and Z are empty vectors if the sample time Ts is undefined.
% 
%     [Wn,Z,P] = DAMP(SYS) also returns the poles P of SYS.
% 
%     When invoked without left-hand arguments, DAMP prints the poles
%     with their natural frequency and damping factor in a tabular format 
%     on the screen.  The poles are sorted by increasing frequency.
% 
%     

function esort
%MATLAB Tour Partial Function Help:  cont_con
%
% ESORT  Sort complex continuous eigenvalues in descending order.
% 
%    S = ESORT(P)  sorts the complex eigenvalues in the vector P in
%    descending order by real part.  The unstable eigenvalues (in
%    the continuous-time sense) will appear first.
% 
%    [S,NDX] = ESORT(P) also returns the vector NDX containing the 
%    indexes used in the sort.
% 
%    

function dsort
%MATLAB Tour Partial Function Help:  cont_con
%
% DSORT  Sort complex discrete eigenvalues in descending order.
% 
%    S = DSORT(P) sorts the complex eigenvalues in the vector P in 
%    descending order by magnitude.  The unstable eigenvalues (in
%    the continuous-time sense) will appear first.
% 
%    [S,NDX] = DSORT(P) also returns the vector NDX containing the 
%    indexes used in the sort.
% 
%    

function hasdelay
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/hasdelay.m ---
%
% HASDELAY  True for LTI models with time delays.
% 
%    HASDELAY(SYS) returns 1 (true) if the LTI model SYS has input, 
%    output, or I/O delays.
% 
%    

function totaldelay
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/totaldelay.m ---
%
% TOTALDELAY  Total time delays between inputs and outputs.
% 
%    TD = TOTALDELAY(SYS) returns the total I/O delays TD for the 
%    LTI model SYS.  The matrix TD combines contributions from
%    the INPUTDELAY, OUTPUTDELAY, and IODELAYMATRIX properties, 
%    (see LTIPROPS for details on these properties).
% 
%    Delays are expressed in seconds for continuous-time models, 
%    and as integer multiples of the sample period for discrete-time 
%    models (to obtain the delay times in seconds, multiply TD by 
%    the sample time SYS.TS).
% 
%    

function delay2z
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for ss/delay2z.m ---
%
% DELAY2Z  Replace delays by poles at z=0 or FRD phase shift.  
% 
%    For discrete-time TF, ZPK, or SS models SYS,
%       SYS = DELAY2Z(SYS) 
%    maps all time delays to poles at z=0.  Specifically, a 
%    delay of k sampling periods is replaced by (1/z)^k.
% 
%    For FRD models, DELAY2Z absorbs all time delays into the 
%    frequency response data, and is applicable to both 
%    continuous- and discrete-time FRDs.
% 
%    

function pade
%MATLAB Tour Partial Function Help:  cont_con
%
% PADE  Pade approximation of time delays.
% 
%    [NUM,DEN] = PADE(T,N) returns the Nth-order Pade approximation 
%    of the continuous-time delay exp(-T*s) in transfer function form.
%    The row vectors NUM and DEN contain the polynomial coefficients  
%    in descending powers of s.
% 
%    When invoked without left-hand argument, PADE(T,N) plots the
%    step and phase responses of the N-th order Pade approximation 
%    and compares them with the exact responses of the time delay
%    (Note: the Pade approximation has unit gain at all frequencies).
% 
%    SYSX = PADE(SYS,N) returns a delay-free approximation SYSX of 
%    the continuous-time delay system SYS by replacing all delays 
%    by their Nth-order Pade approximation.  
% 
%    SYSX = PADE(SYS,NI,NO,NIO) specifies independent approximation
%    orders for each input, output, and I/O delay.  Here NI, NO, and 
%    NIO are integer arrays such that
%      * NI(j) is the approximation order for the j-th input channel
%      * NO(i) is the approximation order for the i-th output channel
%      * NIO(i,j) is the approximation order for the I/O delay from
%        input j to output i.
%    You can use scalar values for NI, NO, or NIO to specify a uniform 
%    approximation order, and use [] when there are no input, output, 
%    or I/O delays.
% 
%    

function ss2ss
%MATLAB Tour Partial Function Help:  cont_con
%
% SS2SS  Change of state coordinates for state-space models.
% 
%    SYS = SS2SS(SYS,T) performs the similarity transformation 
%    z = Tx on the state vector x of the state-space model SYS.  
%    The resulting state-space model is described by:
% 
%                .       -1        
%                z = [TAT  ] z + [TB] u
%                        -1
%                y = [CT   ] z + D u
% 
%    or, in the descriptor case,
% 
%            -1  .       -1        
%        [TET  ] z = [TAT  ] z + [TB] u
%                        -1
%                y = [CT   ] z + D u  .
% 
%    SS2SS is applicable to both continuous- and discrete-time 
%    models.  For LTI arrays SYS, the transformation T is 
%    performed on each individual model in the array.
% 
%    

function canon
%MATLAB Tour Partial Function Help:  cont_con
%
% CANON  Canonical state-space realizations.
% 
%    CSYS = CANON(SYS,TYPE) computes a canonical state-space 
%    realization CSYS of the LTI model SYS.  The string TYPE
%    selects the type of canonical form:
%      'modal'    :  Modal canonical form where the system 
%                    eigenvalues appear on the diagonal. 
%                    The state matrix A must be diagonalizable.
%      'companion':  Companion canonical form where the characteristic
%                    polynomial appears in the right column.
% 
%    [CSYS,T] = CANON(SYS,TYPE) also returns the state transformation 
%    matrix T relating the new state vector z to the old state vector
%    x by z = Tx.  This syntax is only meaningful when SYS is a 
%    state-space model.
% 
%    The modal form is useful for determining the relative controll-
%    ability of the system modes.  Note: the companion form is ill-
%    conditioned and should be avoided if possible.
% 
%    

function gram
%MATLAB Tour Partial Function Help:  cont_con
%
% GRAM  Controllability and observability gramians.
% 
%    Wc = GRAM(SYS,'c') computes the controllability gramian of 
%    the state-space model SYS.  
% 
%    Wo = GRAM(SYS,'o') computes its observability gramian.
% 
%    In both cases, the state-space model SYS should be stable.
%    The gramians are computed by solving the Lyapunov equations:
% 
%      *  A*Wc + Wc*A' + BB' = 0  and   A'*Wo + Wo*A + C'C = 0 
%         for continuous-time systems        
%                dx/dt = A x + B u  ,   y = C x + D u
% 
%      *  A*Wc*A' - Wc + BB' = 0  and   A'*Wo*A - Wo + C'C = 0 
%         for discrete-time systems   
%            x[n+1] = A x[n] + B u[n] ,  y[n] = C x[n] + D u[n].
% 
%    For ND arrays of LTI models SYS, Wc and Wo are arrays with N+2 
%    dimensions such that 
%       Wc(:,:,j1,...,jN) = GRAM(SYS(:,:,j1,...,jN),'c') .  
%       Wo(:,:,j1,...,jN) = GRAM(SYS(:,:,j1,...,jN),'o') .  
% 
%    

function ssbal
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/ssbal.m ---
%
% SSBAL  Balancing of state-space model using diagonal similarity.
% 
%    [SYS,T] = SSBAL(SYS) uses BALANCE to compute a diagonal similarity 
%    transformation T such that [T*A/T , T*B ; C/T 0] has approximately 
%    equal row and column norms.  
% 
%    [SYS,T] = SSBAL(SYS,CONDT) specifies an upper bound CONDT on the 
%    condition number of T.  Since balancing with ill-conditioned T 
%    can inadvertly magnify round-off errors, CONDT gives control over
%    the worst-case round-off amplification.  The default value is 
%    CONDT = 1/eps.
% 
%    For arrays of state-space models, SSBAL computes a single 
%    transformation T that equalizes the maximum row and column norms 
%    across the entire array.
% 
%    

function balreal
%MATLAB Tour Partial Function Help:  cont_con
%
% BALREAL  Gramian-based balancing of state-space realizations.
% 
%    SYSb = BALREAL(SYS) returns a balanced state-space realization 
%    of the reachable, observable, stable system SYS.
% 
%    [SYSb,G,T,Ti] = BALREAL(SYS) also returns a vector G containing
%    the diagonal of the Gramian of the balanced realization.  The
%    matrices T is the state transformation xb = Tx used to convert SYS
%    to SYSb, and Ti is its inverse.  
% 
%    If the system is normalized properly, small elements in the balanced
%    Gramian G indicate states that can be removed to reduce the model 
%    to lower order.
% 
%    

function modred
%MATLAB Tour Partial Function Help:  cont_con
%
% MODRED  Model state reduction.
% 
%    RSYS = MODRED(SYS,ELIM) or RSYS = MODRED(SYS,ELIM,'mdc') reduces 
%    the order of the state-space model SYS by eliminating the states 
%    specified in vector ELIM.  The state vector is partitioned into X1, 
%    to be kept, and X2, to be eliminated,
% 
%        A = |A11  A12|      B = |B1|    C = |C1 C2|
%            |A21  A22|          |B2|
%        .
%        x = Ax + Bu,   y = Cx + Du  (or discrete time counterpart).
% 
%    The derivative of X2 is set to zero, and the resulting equations
%    solved for X1.  The resulting system has LENGTH(ELIM) fewer states
%    and can be envisioned as having set the ELIM states to be infinitely 
%    fast.  The original and reduced models have matching DC gains 
%    (steady-state response).
% 
%    RSYS = MODRED(SYS,ELIM,'del') simply deletes the states X2.  This
%    typically produces a better approximation in the frequency domain,
%    but the DC gains are not guaranteed to match.
% 
%    If SYS has been balanced with BALREAL and the gramians have M 
%    small diagonal entries, you can reduce the model order by 
%    eliminating the last M states with MODRED.
% 
%    

function minreal
%MATLAB Tour Partial Function Help:  cont_con
%
% MINREAL  Minimal realization and pole-zero cancellation.
% 
%    MSYS = MINREAL(SYS) produces, for a given LTI model SYS, an
%    equivalent model MSYS where all cancelling pole/zero pairs
%    or non minimal state dynamics are eliminated.  For state-space 
%    models, MINREAL produces a minimal realization MSYS of SYS where 
%    all uncontrollable or unobservable modes have been removed.
% 
%    MSYS = MINREAL(SYS,TOL) further specifies the tolerance TOL
%    used for pole-zero cancellation or state dynamics elimination. 
%    The default value is TOL=SQRT(EPS) and increasing this tolerance
%    forces additional cancellations.
% 
%    For a state-space model SYS=SS(A,B,C,D),
%       [MSYS,U] = MINREAL(SYS)
%    also returns an orthogonal matrix U such that (U*A*U',U*B,C*U') 
%    is a Kalman decomposition of (A,B,C). 
% 
%    

function sminreal
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for lti/sminreal.m ---
%
% SMINREAL  Compute a structurally minimal realization.
% 
%    MSYS = SMINREAL(SYS) eliminates the states of the state-space
%    model SYS that are not connected to any input or output.  The
%    resulting state-space model MSYS is equivalent to SYS and is 
%    structurally minimal, i.e., minimal when all nonzero entries 
%    of SYS.A, SYS.B, SYS.C, and SYS.E are set to 1.
% 
%    

function ltiview
%MATLAB Tour Partial Function Help:  cont_con
%
% LTIVIEW Open the LTI Viewer
%    LTIVIEW issued from the command line initializes an empty LTI Viewer.
%    The LTI Viewer is an interactive user-interface for performing the
%    various Control System Toolbox response functions for any state space, 
%    transfer function, or zero-pole-gain LTI object in the workspace.
% 
%    LTIVIEW(PLOTTYPE) opens an LTI Viewer initialized with the response
%    types listed in PLOTTYPE.  The response of a random 4 state, 2 input,
%    2 output state space LTI Object is plotted.
% 
%    PLOTTYPE may be any of the following strings.
% 
%           1) 'step'
%           2) 'impulse'
%           3) 'bode'
%           4) 'nyquist'
%           5) 'nichols'
%           6) 'sigma'
%           7) 'pzmap'
%           8) 'lsim'
%           9) 'initial'
% 
%    PLOTTYPE can also be a cell array of up to 6 of the previous plot type 
%    strings.  The LTI Viewer will contain one response area for each plot type
%    listed in PLOTTYPE.
% 
%    Examples:
%      ltiview({'step';'impulse'});
% 
%    LTIVIEW(PLOTTYPE,SYS1,SYS2,...SYSN) initializes a new LTI Viewer with the
%    responses of the LTI objects SYS#.  You can also specify a color, line 
%    style, and marker for each system, as in
%    LTIVIEW(PLOTTYPE,SYS1,PLOTSTR1,SYS2,PLOTSTR2,...SYSN,PLOTSTRN) 
% 
%    Examples:
%      sys1 = rss(3,2,2);
%      sys2 = rss(4,2,2);
%      ltiview('step',sys1,'r-*',sys2,'m--');
% 
%    LTIVIEW(PLOTTYPE,SYS,OPTIONS) allows the additional input 
%    arguments supported by the different response types to be entered.
%    See the appropriate HELP text for each response type for more
%    details on the format of these extra arguments. In the case of LSIM
%    and INITIAL, the OPTIONS field must include the input signal or
%    initial condition, respectively. OPTIONS can not be added when
%    PLOTTYPE is a cell array.
% 
%    Two additional options for the PLOTTYPE string are available for 
%    manipulating previously opened LTI Viewers:
% 
%    LTIVIEW('clear',Hviewers) clears the plots and data from the LTI Viewers
%    with the handles provided in Hviewers.
% 
%    LTIVIEW('current',SYS1,PLOTSTR1,SYS2,PLOTSTR2,...SYSN,PLOTSTRN,Hviewers)
%    appends the responses for the systems in SYS# to the LTI Viewers with the
%    handles provided in Hviewers, if the systems have the same dimensions as
%    those currently in the LTI Viewer. If the dimensions are different, the LTI 
%    Viewer is first cleared and only the new responses are shown. 

function step
%MATLAB Tour Partial Function Help:  cont_con
%
% STEP  Step response of LTI models.
% 
%    STEP(SYS) plots the step response of the LTI model SYS (created 
%    with either TF, ZPK, or SS).  For multi-input models, independent
%    step commands are applied to each input channel.  The time range 
%    and number of points are chosen automatically.
% 
%    STEP(SYS,TFINAL) simulates the step response from t=0 to the 
%    final time t=TFINAL.  For discrete-time models with unspecified 
%    sampling time, TFINAL is interpreted as the number of samples.
% 
%    STEP(SYS,T) uses the user-supplied time vector T for simulation. 
%    For discrete-time models, T should be of the form  Ti:Ts:Tf 
%    where Ts is the sample time.  For continuous-time models,
%    T should be of the form  Ti:dt:Tf  where dt will become the sample 
%    time for the discrete approximation to the continuous system.  The
%    step input is always assumed to start at t=0 (regardless of Ti).
% 
%    STEP(SYS1,SYS2,...,T) plots the step response of multiple LTI
%    models SYS1,SYS2,... on a single plot.  The time vector T is 
%    optional.  You can also specify a color, line style, and marker 
%    for each system, as in 
%       step(sys1,'r',sys2,'y--',sys3,'gx').
% 
%    When invoked with left-hand arguments,
%       [Y,T] = STEP(SYS)
%    returns the output response Y and the time vector T used for 
%    simulation.  No plot is drawn on the screen.  If SYS has NY
%    outputs and NU inputs, and LT=length(T), Y is an array of
%    size [LT NY NU] where Y(:,:,j) gives the step response of the 
%    j-th input channel.
% 
%    For state-space models, 
%       [Y,T,X] = STEP(SYS) 
%    also returns the state trajectory X which is an LT-by-NX-by-NU
%    array if SYS has NX states.
% 
%    

function impulse
%MATLAB Tour Partial Function Help:  cont_con
%
% IMPULSE  Impulse response of LTI models.
% 
%    IMPULSE(SYS) plots the impulse response of the LTI model SYS (created 
%    with either TF, ZPK, or SS).  For multi-input models, independent
%    impulse commands are applied to each input channel.  The time 
%    range and number of points are chosen automatically.  For continuous 
%    systems with direct feedthrough, the infinite pulse at t=0 is 
%    disregarded.
% 
%    IMPULSE(SYS,TFINAL) simulates the impulse response from t=0 to the 
%    final time t=TFINAL.  For discrete-time systems with unspecified 
%    sampling time, TFINAL is interpreted as the number of samples.
% 
%    IMPULSE(SYS,T) uses the user-supplied time vector T for simulation. 
%    For discrete-time models, T should be of the form  Ti:Ts:Tf  
%    where Ts is the sample time.  For continuous-time models, 
%    T should be of the form  Ti:dt:Tf  where dt will become the sample 
%    time of a discrete approximation to the continuous system.  The
%    impulse is always assumed to arise at t=0 (regardless of Ti).
% 
%    IMPULSE(SYS1,SYS2,...,T) plots the step response of multiple
%    LTI models SYS1,SYS2,... on a single plot.  The time vector T is 
%    optional.  You can also specify a color, line style, and marker 
%    for each system, as in  
%       impulse(sys1,'r',sys2,'y--',sys3,'gx').
% 
%    When invoked with left-hand arguments,
%       [Y,T] = IMPULSE(SYS) 
%    returns the output response Y and the time vector T used for 
%    simulation.  No plot is drawn on the screen.  If SYS has NY
%    outputs and NU inputs, and LT=length(T), Y is an array of size
%    [LT NY NU] where Y(:,:,j) gives the impulse response of the 
%    j-th input channel.
% 
%    For state-space models, 
%       [Y,T,X] = IMPULSE(SYS, ...) 
%    also returns the state trajectory X which is an LT-by-NX-by-NU 
%    array if SYS has NX states.
% 
%    

function initial
%MATLAB Tour Partial Function Help:  cont_con
%
% INITIAL  Initial condition response of state-space models.
% 
%    INITIAL(SYS,X0) plots the undriven response of the state-space 
%    model SYS with initial condition X0 on the states.  This 
%    response is characterized by the equations
%                         .
%      Continuous time:   x = A x ,  y = C x ,  x(0) = x0 
% 
%      Discrete time:  x[k+1] = A x[k],  y[k] = C x[k],  x[0] = x0 .
% 
%    The time range and number of points are chosen automatically.  
% 
%    INITIAL(SYS,X0,TFINAL) simulates the time response from t=0 
%    to the final time t=TFINAL.  For discrete-time models with 
%    unspecified sample time, TFINAL should be the number of samples.
% 
%    INITIAL(SYS,X0,T) specifies a time vector T to be used for 
%    simulation.  For discrete systems, T should be of the form  
%    0:Ts:Tf where Ts is the sample time.  For continuous-time models,
%    T should be of the form 0:dt:Tf where dt will become the sample
%    time of a discrete approximation of the continuous model.
% 
%    INITIAL(SYS1,SYS2,...,X0,T) plots the response of multiple LTI 
%    models SYS1,SYS2,... on a single plot.  The time vector T is 
%    optional.  You can also specify a color, line style, and marker 
%    for each system, as in  
%       initial(sys1,'r',sys2,'y--',sys3,'gx',x0).
% 
%    When invoked with left hand arguments,
%       [Y,T,X] = INITIAL(SYS,X0)
%    returns the output response Y, the time vector T used for simulation, 
%    and the state trajectories X.  No plot is drawn on the screen.  The
%    matrix Y has LENGTH(T) rows and as many columns as outputs in SYS.
%    Similarly, X has LENGTH(T) rows and as many columns as states.
% 	
%    

function lsim
%MATLAB Tour Partial Function Help:  cont_con
%
% LSIM  Simulate time response of LTI models to arbitrary inputs.
% 
%    LSIM(SYS,U,T) plots the time response of the LTI model SYS to the
%    input signal described by U and T.  The time vector T consists of 
%    regularly spaced time samples and U is a matrix with as many columns 
%    as inputs and whose i-th row specifies the input value at time T(i).
%    For example, 
%            t = 0:0.01:5;   u = sin(t);   lsim(sys,u,t)  
%    simulates the response of a single-input model SYS to the input 
%    u(t)=sin(t) during 5 seconds.
% 
%    For discrete-time models, U should be sampled at the same rate as SYS
%    (T is then redundant and can be omitted or set to the empty matrix).
%    For continuous-time models, choose the sampling period T(2)-T(1) small 
%    enough to accurately describe the input U.  LSIM checks for intersample 
%    oscillations and resamples U if necessary.
%          
%    LSIM(SYS,U,T,X0) specifies an additional nonzero initial state X0
%    (for state-space models only).
% 
%    LSIM(SYS1,SYS2,...,U,T,X0)  simulates the response of multiple LTI
%    models SYS1,SYS2,... on a single plot.  The initial condition X0 
%    is optional.  You can also specify a color, line style, and marker 
%    for each system, as in  
%       lsim(sys1,'r',sys2,'y--',sys3,'gx',u,t).
% 
%    When invoked with left-hand arguments,
%       [YS,TS] = LSIM(SYS,U,T)
%    returns the output history YS and time vector TS used for simulation.
%    No plot is drawn on the screen.  The matrix YS has LENGTH(TS) rows 
%    and as many columns as outputs in SYS.
%    WARNING: TS contains more points than T when U is resampled to reveal
%    intersample oscillations.  To get the response at the samples T only,
%    extract YS(1:d:end,:) where d=round(length(TS)/length(T)).
% 
%    For state-space models, 
%       [YS,TS,XS] = LSIM(SYS,U,T,X0) 
%    also returns the state trajectory XS, a matrix with LENGTH(TS) rows
%    and as many columns as states.
% 
%    

function gensig
%MATLAB Tour Partial Function Help:  cont_con
%
% GENSIG  Periodic signal generator for time response simulations with LSIM.
% 
%       [U,T] = GENSIG(TYPE,TAU)  generates a scalar signal U of class TYPE
%       and period TAU.  The following classes are supported:
%             TYPE = 'sin'        ---   sine wave
%             TYPE = 'square'     ---   square wave
%             TYPE = 'pulse'      ---   periodic pulse
%       GENSIG returns a vector T of time samples and the vector U of signal
%       values at these samples.  All generated signals have unit amplitude.
% 
%       [U,T] = GENSIG(TYPE,TAU,TF,TS)  further specifies the time duration TF
%       of the signal and the spacing TS of the time samples in T.
% 
%       

function stepfun
%MATLAB Tour Partial Function Help:  cont_con
%
% STEPFUN  Unit step function.
% 
%    STEPFUN(T,T0), where T is a monotonically increasing vector,
%    returns a vector the same length as T with zeros where T < T0
%    and ones where T >= T0.

function bode
%MATLAB Tour Partial Function Help:  cont_con
%
% BODE  Bode frequency response of LTI models.
% 
%    BODE(SYS) draws the Bode plot of the LTI model SYS (created with
%    either TF, ZPK, SS, or FRD).  The frequency range and number of  
%    points are chosen automatically.
% 
%    BODE(SYS,{WMIN,WMAX}) draws the Bode plot for frequencies
%    between WMIN and WMAX (in radians/second).
% 
%    BODE(SYS,W) uses the user-supplied vector W of frequencies,
%    in radian/second, at which the Bode response is to be evaluated.  
%    See LOGSPACE to generate logarithmically spaced frequency vectors.
% 
%    BODE(SYS1,SYS2,...,W) plots the Bode response of multiple LTI
%    models SYS1,SYS2,... on a single plot.  The frequency vector W
%    is optional.  You can also specify a color, line style, and marker 
%    for each system, as in  
%       bode(sys1,'r',sys2,'y--',sys3,'gx').
% 
%    [MAG,PHASE] = BODE(SYS,W) and [MAG,PHASE,W] = BODE(SYS) return the
%    response magnitudes and phases in degrees (along with the frequency 
%    vector W if unspecified).  No plot is drawn on the screen.  
%    If SYS has NY outputs and NU inputs, MAG and PHASE are arrays of 
%    size [NY NU LENGTH(W)] where MAG(:,:,k) and PHASE(:,:,k) determine 
%    the response at the frequency W(k).  To get the magnitudes in dB, 
%    type MAGDB = 20*log10(MAG).
% 
%    For discrete-time models with sample time Ts, BODE uses the
%    transformation Z = exp(j*W*Ts) to map the unit circle to the 
%    real frequency axis.  The frequency response is only plotted 
%    for frequencies smaller than the Nyquist frequency pi/Ts, and 
%    the default value 1 (second) is assumed when Ts is unspecified.
% 
%    

function sigma
%MATLAB Tour Partial Function Help:  cont_con
%
% SIGMA  Singular value plot of LTI models.
% 
%    SIGMA(SYS) produces a singular value (SV) plot of the frequency 
%    response of the LTI model SYS (created with TF, ZPK, SS, or FRD).  
%    The frequency range and number of points are chosen automatically.  
%    See BODE for details on the notion of frequency in discrete time.
% 
%    SIGMA(SYS,{WMIN,WMAX})  draws the SV plot for frequencies ranging
%    between WMIN and WMAX (in radian/second).
% 
%    SIGMA(SYS,W) uses the user-supplied vector W of frequencies, in
%    radians/second, at which the frequency response is to be evaluated.  
%    See LOGSPACE to generate logarithmically spaced frequency vectors.
% 
%    SIGMA(SYS,W,TYPE) or SIGMA(SYS,[],TYPE) draws the following
%    modified SV plots depending on the value of TYPE:
%           TYPE = 1     -->     SV of  inv(SYS)
%           TYPE = 2     -->     SV of  I + SYS
%           TYPE = 3     -->     SV of  I + inv(SYS) 
%    SYS should be a square system when using this syntax.
% 
%    SIGMA(SYS1,SYS2,...,W,TYPE) draws the SV response of several LTI
%    models SYS1,SYS2,... on a single plot.  The arguments W and TYPE
%    are optional.  You can also specify a color, line style, and marker 
%    for each system, as in  sigma(sys1,'r',sys2,'y--',sys3,'gx').
%    
%    SV = SIGMA(SYS,W) and [SV,W] = SIGMA(SYS) return the singular 
%    values SV of the frequency response (along with the frequency 
%    vector W if unspecified).  No plot is drawn on the screen. 
%    The matrix SV has length(W) columns and SV(:,k) gives the
%    singular values (in descending order) at the frequency W(k).
% 
%    For details on Robust Control Toolbox syntax, type HELP RSIGMA.
% 
%    

function nyquist
%MATLAB Tour Partial Function Help:  cont_con
%
% NYQUIST  Nyquist frequency response of LTI models.
% 
%    NYQUIST(SYS) draws the Nyquist plot of the LTI model SYS
%    (created with either TF, ZPK, SS, or FRD).  The frequency range 
%    and number of points are chosen automatically.  See BODE for  
%    details on the notion of frequency in discrete-time.
% 
%    NYQUIST(SYS,{WMIN,WMAX}) draws the Nyquist plot for frequencies
%    between WMIN and WMAX (in radians/second).
% 
%    NYQUIST(SYS,W) uses the user-supplied vector W of frequencies 
%    (in radian/second) at which the Nyquist response is to be evaluated.  
%    See LOGSPACE to generate logarithmically spaced frequency vectors.
% 
%    NYQUIST(SYS1,SYS2,...,W) plots the Nyquist response of multiple
%    LTI models SYS1,SYS2,... on a single plot.  The frequency vector
%    W is optional.  You can also specify a color, line style, and marker 
%    for each system, as in  
%       nyquist(sys1,'r',sys2,'y--',sys3,'gx').
% 
%    [RE,IM] = NYQUIST(SYS,W) and [RE,IM,W] = NYQUIST(SYS) return the
%    real parts RE and imaginary parts IM of the frequency response 
%    (along with the frequency vector W if unspecified).  No plot is 
%    drawn on the screen.  If SYS has NY outputs and NU inputs,
%    RE and IM are arrays of size [NY NU LENGTH(W)] and the response 
%    at the frequency W(k) is given by RE(:,:,k)+j*IM(:,:,k).
% 
%    

function nichols
%MATLAB Tour Partial Function Help:  cont_con
%
% NICHOLS  Nichols frequency response of LTI models.
% 
%    NICHOLS(SYS) draws the Nichols chart of the LTI model SYS
%    (created with either TF, ZPK, SS, or FRD).  The frequency range  
%    and number of points are chosen automatically.  See BODE for  
%    details on the notion of frequency in discrete-time.
% 
%    NICHOLS(SYS,{WMIN,WMAX}) draws the Nichols chart for frequencies
%    between WMIN and WMAX (in radian/second).
% 
%    NICHOLS(SYS,W) uses the user-supplied vector W of frequencies, in
%    radians/second, at which the Nichols response is to be evaluated.  
%    See LOGSPACE to generate logarithmically spaced frequency vectors.
% 
%    NICHOLS(SYS1,SYS2,...,W) plots the Nichols chart of multiple LTI
%    models SYS1,SYS2,... on a single plot.  The frequency vector W
%    is optional.  You can also specify a color, line style, and marker 
%    for each system, as in  
%       nichols(sys1,'r',sys2,'y--',sys3,'gx').
% 
%    [MAG,PHASE] = NICHOLS(SYS,W) and [MAG,PHASE,W] = NICHOLS(SYS) return
%    the response magnitudes and phases in degrees (along with the 
%    frequency vector W if unspecified).  No plot is drawn on the screen.  
%    If SYS has NY outputs and NU inputs, MAG and PHASE are arrays of 
%    size [NY NU LENGTH(W)] where MAG(:,:,k) and PHASE(:,:,k) determine 
%    the response at the frequency W(k).
% 
%    

function margin
%MATLAB Tour Partial Function Help:  cont_con
%
% MARGIN  Gain and phase margins and crossover frequencies.
% 
%    [Gm,Pm,Wcg,Wcp] = MARGIN(SYS) computes the gain margin Gm, the
%    phase margin Pm in degrees, and the associated frequencies 
%    Wcg and Wcp, for a SISO open-loop LTI model SYS (continuous or 
%    discrete).  The gain margin Gm is defined as 1/G where G is 
%    the gain at the -180 phase crossing.  The gain margin in dB 
%    is 20*log10(Gm).  By convention, Gm=1 (0 dB) and Pm=0 when 
%    the nominal closed loop is unstable.
% 
%    [Gm,Pm,Wcg,Wcp] = MARGIN(MAG,PHASE,W) derives the gain and phase
%    margins from the Bode magnitude, phase, and frequency vectors 
%    MAG, PHASE, and W produced by BODE.  Interpolation is performed 
%    between the frequency points to estimate the values. 
% 
%    For a S1-by...-by-Sp array SYS of LTI models, MARGIN returns 
%    arrays of size [S1 ... Sp] such that
%       [Gm(j1,...,jp),Pm(j1,...,jp)] = MARGIN(SYS(:,:,j1,...,jp)) .  
% 
%    When invoked without left hand arguments, MARGIN(SYS) plots
%    the open-loop Bode plot with the gain and phase margins marked 
%    with a vertical line.  
% 
%    

function freqresp
%MATLAB Tour Partial Function Help:  cont_con
%
% FREQRESP  Frequency response of LTI models.
% 
%    H = FREQRESP(SYS,W) computes the frequency response H of the 
%    LTI model SYS at the frequencies specified by the vector W.
%    These frequencies should be real and in radians/second.  
% 
%    If SYS has NY outputs and NU inputs, and W contains NW frequencies, 
%    the output H is a NY-by-NU-by-NW array such that H(:,:,k) gives 
%    the response at the frequency W(k).
% 
%    If SYS is a S1-by-...-Sp array of LTI models with NY outputs and 
%    NU inputs, then SIZE(H)=[NY NU NW S1 ... Sp] where NW=LENGTH(W).
% 
%    

function evalfr
%MATLAB Tour Partial Function Help:  cont_con
%
% --- help for ss/evalfr.m ---
%
% EVALFR  Evaluate frequency response at a single (complex) frequency.
% 
%    FRESP = EVALFR(SYS,X) evaluates the transfer function of the 
%    continuous- or discrete-time LTI model SYS at the complex 
%    number S=X or Z=X.  For state-space models, the result is
%                                    -1
%        FRESP =  D + C * (X * E - A)  * B   .
% 
%    EVALFR is a simplified version of FREQRESP meant for quick 
%    evaluation of the response at a single point.  Use FREQRESP 
%    to compute the frequency response over a grid of frequencies.
% 
%    

function append
%MATLAB Tour Partial Function Help:  cont_con
%
% APPEND  Group LTI models by appending their inputs and outputs.
% 
%    SYS = APPEND(SYS1,SYS2, ...) produces the aggregate system
%  
%                  [ SYS1  0       ]
%            SYS = [  0   SYS2     ]
%                  [           .   ]
%                  [             . ]
% 
%    APPEND concatenates the input and output vectors of the LTI
%    models SYS1, SYS2,... to produce the resulting model SYS.
% 
%    If SYS1,SYS2,... are arrays of LTI models, APPEND returns an LTI
%    array SYS of the same size where 
%       SYS(:,:,k) = APPEND(SYS1(:,:,k),SYS2(:,:,k),...) .
% 
%    

function parallel
%MATLAB Tour Partial Function Help:  cont_con
%
% PARALLEL  Parallel interconnection of two LTI models.
% 
%                           +------+
%             v1 ---------->|      |----------> z1
%                           | SYS1 |
%                    u1 +-->|      |---+ y1
%                       |   +------+   |
%              u ------>+              O------> y
%                       |   +------+   |
%                    u2 +-->|      |---+ y2
%                           | SYS2 |
%             v2 ---------->|      |----------> z2
%                           +------+
% 
%    SYS = PARALLEL(SYS1,SYS2,IN1,IN2,OUT1,OUT2) connects the two 
%    LTI models SYS1 and SYS2 in parallel such that the inputs 
%    specified by IN1 and IN2 are connected and the outputs specified
%    by OUT1 and OUT2 are summed.  The resulting LTI model SYS maps 
%    [v1;u;v2] to [z1;y;z2].  The vectors IN1 and IN2 contain indexes 
%    into the input vectors of SYS1 and SYS2, respectively, and define 
%    the input channels u1 and u2 in the diagram.  Similarly, the 
%    vectors OUT1 and OUT2 contain indexes into the outputs of these 
%    two systems. 
% 
%    If IN1,IN2,OUT1,OUT2 are jointly omitted, PARALLEL forms the 
%    standard parallel interconnection of SYS1 and SYS2 and returns
%           SYS = SYS2 + SYS1 .
% 
%    If SYS1 and SYS2 are arrays of LTI models, PARALLEL returns an LTI
%    array SYS of the same size where 
%       SYS(:,:,k) = PARALLEL(SYS1(:,:,k),SYS2(:,:,k),IN1,...) .
% 
%    

